@@ -131,9 +131,9 @@ void sanitizeInstrument(instr_t *ins)
 	ins->midiBend = CLAMP(ins->midiBend, 0, 36);
 
 	if (ins->midiChannel > 15) ins->midiChannel = 15;
-	if (ins->vibDepth > 0x0F) ins->vibDepth = 0x0F;
-	if (ins->vibRate > 0x3F) ins->vibRate = 0x3F;
-	if (ins->vibType > 3) ins->vibType = 0;
+	if (ins->autoVibDepth > 0x0F) ins->autoVibDepth = 0x0F;
+	if (ins->autoVibRate > 0x3F) ins->autoVibRate = 0x3F;
+	if (ins->autoVibType > 3) ins->autoVibType = 0;
 
 	for (int32_t i = 0; i < 96; i++)
 	{
@@ -212,7 +212,7 @@ static int32_t SDLCALL copyInstrThread(void *ptr)
 	resumeAudio();
 
 	if (error)
-		okBoxThreadSafe(0, "System message", "Not enough memory!");
+		okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 
 	// do not change instrument names!
 
@@ -237,7 +237,7 @@ void copyInstr(void) // dstInstr = srcInstr
 	thread = SDL_CreateThread(copyInstrThread, NULL, NULL);
 	if (thread == NULL)
 	{
-		okBox(0, "System message", "Couldn't create thread!");
+		okBox(0, "System message", "Couldn't create thread!", NULL);
 		return;
 	}
 
@@ -537,17 +537,17 @@ static void drawFadeout(void)
 
 static void drawVibSpeed(void)
 {
-	hexOutBg(505, 236, PAL_FORGRND, PAL_DESKTOP, getCurDispInstr()->vibRate, 2);
+	hexOutBg(505, 236, PAL_FORGRND, PAL_DESKTOP, getCurDispInstr()->autoVibRate, 2);
 }
 
 static void drawVibDepth(void)
 {
-	hexOutBg(512, 250, PAL_FORGRND, PAL_DESKTOP, getCurDispInstr()->vibDepth, 1);
+	hexOutBg(512, 250, PAL_FORGRND, PAL_DESKTOP, getCurDispInstr()->autoVibDepth, 1);
 }
 
 static void drawVibSweep(void)
 {
-	hexOutBg(505, 264, PAL_FORGRND, PAL_DESKTOP, getCurDispInstr()->vibSweep, 2);
+	hexOutBg(505, 264, PAL_FORGRND, PAL_DESKTOP, getCurDispInstr()->autoVibSweep, 2);
 }
 
 static void drawRelativeNote(void)
@@ -598,10 +598,10 @@ static void setStdVolEnvelope(instr_t *ins, uint8_t num)
 	ins->volEnvLoopEnd = (uint8_t)config.stdVolEnvLoopEnd[num];
 	ins->volEnvLength = (uint8_t)config.stdVolEnvLength[num];
 	ins->volEnvFlags = (uint8_t)config.stdVolEnvFlags[num];
-	ins->vibRate = (uint8_t)config.stdVibRate[num];
-	ins->vibDepth = (uint8_t)config.stdVibDepth[num];
-	ins->vibSweep = (uint8_t)config.stdVibSweep[num];
-	ins->vibType = (uint8_t)config.stdVibType[num];
+	ins->autoVibRate = (uint8_t)config.stdVibRate[num];
+	ins->autoVibDepth = (uint8_t)config.stdVibDepth[num];
+	ins->autoVibSweep = (uint8_t)config.stdVibSweep[num];
+	ins->autoVibType = (uint8_t)config.stdVibType[num];
 
 	memcpy(ins->volEnvPoints, config.stdEnvPoints[num][0], sizeof (int16_t) * 12 * 2);
 
@@ -641,10 +641,10 @@ static void setOrStoreVolEnvPreset(uint8_t num)
 		config.stdVolEnvLoopEnd[num] = ins->volEnvLoopEnd;
 		config.stdVolEnvLength[num] = ins->volEnvLength;
 		config.stdVolEnvFlags[num] = ins->volEnvFlags;
-		config.stdVibRate[num] = ins->vibRate;
-		config.stdVibDepth[num] = ins->vibDepth;
-		config.stdVibSweep[num] = ins->vibSweep;
-		config.stdVibType[num] = ins->vibType;
+		config.stdVibRate[num] = ins->autoVibRate;
+		config.stdVibDepth[num] = ins->autoVibDepth;
+		config.stdVibSweep[num] = ins->autoVibSweep;
+		config.stdVibType[num] = ins->autoVibType;
 
 		memcpy(config.stdEnvPoints[num][0], ins->volEnvPoints, sizeof (int16_t) * 12 * 2);
 	}
@@ -673,10 +673,10 @@ static void setOrStorePanEnvPreset(uint8_t num)
 		config.stdPanEnvLoopEnd[num] = ins->panEnvLoopEnd;
 		config.stdPanEnvLength[num] = ins->panEnvLength;
 		config.stdPanEnvFlags[num] = ins->panEnvFlags;
-		config.stdVibRate[num] = ins->vibRate;
-		config.stdVibDepth[num] = ins->vibDepth;
-		config.stdVibSweep[num] = ins->vibSweep;
-		config.stdVibType[num] = ins->vibType;
+		config.stdVibRate[num] = ins->autoVibRate;
+		config.stdVibDepth[num] = ins->autoVibDepth;
+		config.stdVibSweep[num] = ins->autoVibSweep;
+		config.stdVibType[num] = ins->autoVibType;
 
 		memcpy(config.stdEnvPoints[num][1], ins->panEnvPoints, sizeof (int16_t) * 12 * 2);
 	}
@@ -1376,9 +1376,9 @@ void setVibSpeedScroll(uint32_t pos)
 		return;
 	}
 
-	if (ins->vibRate != (uint8_t)pos)
+	if (ins->autoVibRate != (uint8_t)pos)
 	{
-		ins->vibRate = (uint8_t)pos;
+		ins->autoVibRate = (uint8_t)pos;
 		drawVibSpeed();
 		setSongModifiedFlag();
 	}
@@ -1393,9 +1393,9 @@ void setVibDepthScroll(uint32_t pos)
 		return;
 	}
 
-	if (ins->vibDepth != (uint8_t)pos)
+	if (ins->autoVibDepth != (uint8_t)pos)
 	{
-		ins->vibDepth = (uint8_t)pos;
+		ins->autoVibDepth = (uint8_t)pos;
 		drawVibDepth();
 		setSongModifiedFlag();
 	}
@@ -1410,9 +1410,9 @@ void setVibSweepScroll(uint32_t pos)
 		return;
 	}
 
-	if (ins->vibSweep != (uint8_t)pos)
+	if (ins->autoVibSweep != (uint8_t)pos)
 	{
-		ins->vibSweep = (uint8_t)pos;
+		ins->autoVibSweep = (uint8_t)pos;
 		drawVibSweep();
 		setSongModifiedFlag();
 	}
@@ -1423,7 +1423,7 @@ void rbVibWaveSine(void)
 	if (instr[editor.curInstr] == NULL || editor.curInstr == 0)
 		return;
 
-	instr[editor.curInstr]->vibType = 0;
+	instr[editor.curInstr]->autoVibType = 0;
 
 	uncheckRadioButtonGroup(RB_GROUP_INST_WAVEFORM);
 	radioButtons[RB_INST_WAVE_SINE].state = RADIOBUTTON_CHECKED;
@@ -1436,7 +1436,7 @@ void rbVibWaveSquare(void)
 	if (instr[editor.curInstr] == NULL || editor.curInstr == 0)
 		return;
 
-	instr[editor.curInstr]->vibType = 1;
+	instr[editor.curInstr]->autoVibType = 1;
 
 	uncheckRadioButtonGroup(RB_GROUP_INST_WAVEFORM);
 	radioButtons[RB_INST_WAVE_SQUARE].state = RADIOBUTTON_CHECKED;
@@ -1449,7 +1449,7 @@ void rbVibWaveRampDown(void)
 	if (instr[editor.curInstr] == NULL || editor.curInstr == 0)
 		return;
 
-	instr[editor.curInstr]->vibType = 2;
+	instr[editor.curInstr]->autoVibType = 2;
 
 	uncheckRadioButtonGroup(RB_GROUP_INST_WAVEFORM);
 	radioButtons[RB_INST_WAVE_RAMP_DOWN].state = RADIOBUTTON_CHECKED;
@@ -1462,7 +1462,7 @@ void rbVibWaveRampUp(void)
 	if (instr[editor.curInstr] == NULL || editor.curInstr == 0)
 		return;
 
-	instr[editor.curInstr]->vibType = 3;
+	instr[editor.curInstr]->autoVibType = 3;
 
 	uncheckRadioButtonGroup(RB_GROUP_INST_WAVEFORM);
 	radioButtons[RB_INST_WAVE_RAMP_UP].state = RADIOBUTTON_CHECKED;
@@ -1702,7 +1702,7 @@ void drawPiano(chSyncData_t *chSyncData)
 			channel_t *c = channel;
 			for (int32_t i = 0; i < song.numChannels; i++, c++)
 			{
-				if (c->instrNum == editor.curInstr && c->envSustainActive)
+				if (c->instrNum == editor.curInstr && !c->keyOff)
 				{
 					const int32_t note = getPianoKey(c->finalPeriod, c->finetune, c->relativeNote);
 					if (note >= 0 && note <= 95)
@@ -2001,7 +2001,7 @@ static void writeEnvelope(int32_t envNum)
 
 static void drawVolEnvCoords(int16_t tick, int16_t val)
 {
-	char str[4];
+	char str[8];
 
 	tick = CLAMP(tick, 0, 324);
 	sprintf(str, "%03d", tick);
@@ -2014,13 +2014,14 @@ static void drawVolEnvCoords(int16_t tick, int16_t val)
 
 static void drawPanEnvCoords(int16_t tick, int16_t val)
 {
-	bool negative = false;
-	char str[4];
+	char str[8];
 
 	tick = CLAMP(tick, 0, 324);
 	sprintf(str, "%03d", tick);
 	textOutTinyOutline(326, 277, str);
 	
+	bool negative = false;
+	
 	val -= 32;
 	val = CLAMP(val, -32, 31);
 	if (val < 0)
@@ -2214,14 +2215,14 @@ void updateInstEditor(void)
 	setScrollBarPos(SB_INST_PAN, s->panning, false);
 	setScrollBarPos(SB_INST_FTUNE, 128 + s->finetune, false);
 	setScrollBarPos(SB_INST_FADEOUT, ins->fadeout, false);
-	setScrollBarPos(SB_INST_VIBSPEED, ins->vibRate, false);
-	setScrollBarPos(SB_INST_VIBDEPTH, ins->vibDepth, false);
-	setScrollBarPos(SB_INST_VIBSWEEP, ins->vibSweep, false);
+	setScrollBarPos(SB_INST_VIBSPEED, ins->autoVibRate, false);
+	setScrollBarPos(SB_INST_VIBDEPTH, ins->autoVibDepth, false);
+	setScrollBarPos(SB_INST_VIBSWEEP, ins->autoVibSweep, false);
 
 	// set radio buttons
 
 	uncheckRadioButtonGroup(RB_GROUP_INST_WAVEFORM);
-	switch (ins->vibType)
+	switch (ins->autoVibType)
 	{
 		default:
 		case 0: tmpID = RB_INST_WAVE_SINE;      break;
@@ -2914,21 +2915,21 @@ static int32_t SDLCALL saveInstrThread(void *ptr)
 
 	if (editor.tmpFilenameU == NULL)
 	{
-		okBoxThreadSafe(0, "System message", "General I/O error during saving! Is the file in use?");
+		okBoxThreadSafe(0, "System message", "General I/O error during saving! Is the file in use?", NULL);
 		return false;
 	}
 
 	const int32_t numSamples = getUsedSamples(saveInstrNum);
 	if (numSamples == 0 || instr[saveInstrNum] == NULL)
 	{
-		okBoxThreadSafe(0, "System message", "Instrument is empty!");
+		okBoxThreadSafe(0, "System message", "Instrument is empty!", NULL);
 		return false;
 	}
 
 	FILE *f = UNICHAR_FOPEN(editor.tmpFilenameU, "wb");
 	if (f == NULL)
 	{
-		okBoxThreadSafe(0, "System message", "General I/O error during saving! Is the file in use?");
+		okBoxThreadSafe(0, "System message", "General I/O error during saving! Is the file in use?", NULL);
 		return false;
 	}
 
@@ -2972,10 +2973,10 @@ static int32_t SDLCALL saveInstrThread(void *ptr)
 	ih.panEnvLoopEnd = ins->panEnvLoopEnd;
 	ih.volEnvFlags = ins->volEnvFlags;
 	ih.panEnvFlags = ins->panEnvFlags;
-	ih.vibType = ins->vibType;
-	ih.vibSweep = ins->vibSweep;
-	ih.vibDepth = ins->vibDepth;
-	ih.vibRate = ins->vibRate;
+	ih.vibType = ins->autoVibType;
+	ih.vibSweep = ins->autoVibSweep;
+	ih.vibDepth = ins->autoVibDepth;
+	ih.vibRate = ins->autoVibRate;
 	ih.fadeout = ins->fadeout;
 	ih.midiOn = ins->midiOn ? 1 : 0;
 	ih.midiChannel = ins->midiChannel;
@@ -3025,7 +3026,7 @@ static int32_t SDLCALL saveInstrThread(void *ptr)
 	if (result != 1)
 	{
 		fclose(f);
-		okBoxThreadSafe(0, "System message", "Error saving instrument: general I/O error!");
+		okBoxThreadSafe(0, "System message", "Error saving instrument: general I/O error!", NULL);
 		return false;
 	}
 
@@ -3047,7 +3048,7 @@ static int32_t SDLCALL saveInstrThread(void *ptr)
 			{
 				resumeAudio();
 				fclose(f);
-				okBoxThreadSafe(0, "System message", "Error saving instrument: general I/O error!");
+				okBoxThreadSafe(0, "System message", "Error saving instrument: general I/O error!", NULL);
 				return false;
 			}
 		}
@@ -3076,7 +3077,7 @@ void saveInstr(UNICHAR *filenameU, int16_t insNum)
 	thread = SDL_CreateThread(saveInstrThread, NULL, NULL);
 	if (thread == NULL)
 	{
-		okBox(0, "System message", "Couldn't create thread!");
+		okBox(0, "System message", "Couldn't create thread!", NULL);
 		return;
 	}
 
@@ -3107,14 +3108,14 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 
 	if (editor.tmpInstrFilenameU == NULL)
 	{
-		okBoxThreadSafe(0, "System message", "General I/O error during loading! Is the file in use?");
+		okBoxThreadSafe(0, "System message", "General I/O error during loading! Is the file in use?", NULL);
 		return false;
 	}
 
 	FILE *f = UNICHAR_FOPEN(editor.tmpInstrFilenameU, "rb");
 	if (f == NULL)
 	{
-		okBoxThreadSafe(0, "System message", "General I/O error during loading! Is the file in use?");
+		okBoxThreadSafe(0, "System message", "General I/O error during loading! Is the file in use?", NULL);
 		return false;
 	}
 
@@ -3129,7 +3130,7 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 
 		if (xi_h.version != 0x0101 && xi_h.version != 0x0102)
 		{
-			okBoxThreadSafe(0, "System message", "Incompatible format version!");
+			okBoxThreadSafe(0, "System message", "Incompatible format version!", NULL);
 			goto loadDone;
 		}
 
@@ -3157,7 +3158,7 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 			if (!allocateInstr(editor.curInstr))
 			{
 				resumeAudio();
-				okBoxThreadSafe(0, "System message", "Not enough memory!");
+				okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 				goto loadDone;
 			}
 
@@ -3177,10 +3178,10 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 			ins->panEnvLoopEnd = xi_h.panEnvLoopEnd;
 			ins->volEnvFlags = xi_h.volEnvFlags;
 			ins->panEnvFlags = xi_h.panEnvFlags;
-			ins->vibType = xi_h.vibType;
-			ins->vibSweep = xi_h.vibSweep;
-			ins->vibDepth = xi_h.vibDepth;
-			ins->vibRate = xi_h.vibRate;
+			ins->autoVibType = xi_h.vibType;
+			ins->autoVibSweep = xi_h.vibSweep;
+			ins->autoVibDepth = xi_h.vibDepth;
+			ins->autoVibRate = xi_h.vibRate;
 			ins->fadeout = xi_h.fadeout;
 			ins->midiOn = (xi_h.midiOn == 1) ? true : false;
 			ins->midiChannel = xi_h.midiChannel;
@@ -3197,7 +3198,7 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 			{
 				freeInstr(editor.curInstr);
 				resumeAudio();
-				okBoxThreadSafe(0, "System message", "General I/O error during loading! Is the file in use?");
+				okBoxThreadSafe(0, "System message", "General I/O error during loading! Is the file in use?", NULL);
 				goto loadDone;
 			}
 
@@ -3260,7 +3261,7 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 				{
 					freeInstr(editor.curInstr);
 					resumeAudio();
-					okBoxThreadSafe(0, "System message", "Not enough memory!");
+					okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 					goto loadDone;
 				}
 
@@ -3269,7 +3270,7 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 				{
 					freeInstr(editor.curInstr);
 					resumeAudio();
-					okBoxThreadSafe(0, "System message", "General I/O error during loading! Is the file in use?");
+					okBoxThreadSafe(0, "System message", "General I/O error during loading! Is the file in use?", NULL);
 					goto loadDone;
 				}
 
@@ -3309,7 +3310,7 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 
 			if (pat_h.layers > 1 || pat_h.numSamples > MAX_SMP_PER_INST)
 			{
-				okBoxThreadSafe(0, "System message", "Incompatible instrument!");
+				okBoxThreadSafe(0, "System message", "Incompatible instrument!", NULL);
 				goto loadDone;
 			}
 
@@ -3320,7 +3321,7 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 
 			if (!allocateInstr(editor.curInstr))
 			{
-				okBoxThreadSafe(0, "System message", "Not enough memory!");
+				okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 				goto loadDone;
 			}
 
@@ -3336,7 +3337,7 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 				{
 					freeInstr(editor.curInstr);
 					resumeAudio();
-					okBoxThreadSafe(0, "System message", "General I/O error during loading! Is the file in use?");
+					okBoxThreadSafe(0, "System message", "General I/O error during loading! Is the file in use?", NULL);
 					goto loadDone;
 				}
 
@@ -3358,15 +3359,15 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 				{
 					freeInstr(editor.curInstr);
 					resumeAudio();
-					okBoxThreadSafe(0, "System message", "Not enough memory!");
+					okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 					goto loadDone;
 				}
 
 				if (i == 0)
 				{
-					ins->vibSweep = patWave_h.vibSweep;
-					ins->vibRate = (patWave_h.vibRate + 2) >> 2; // rounded
-					ins->vibDepth = (patWave_h.vibDepth + 1) >> 1; // rounded
+					ins->autoVibSweep = patWave_h.vibSweep;
+					ins->autoVibRate = (patWave_h.vibRate + 2) >> 2; // rounded
+					ins->autoVibDepth = (patWave_h.vibDepth + 1) >> 1; // rounded
 				}
 
 				s = &instr[editor.curInstr]->smp[i];
@@ -3413,7 +3414,7 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 				{
 					freeInstr(editor.curInstr);
 					resumeAudio();
-					okBoxThreadSafe(0, "System message", "General I/O error during loading! Is the file in use?");
+					okBoxThreadSafe(0, "System message", "General I/O error during loading! Is the file in use?", NULL);
 					goto loadDone;
 				}
 
@@ -3456,10 +3457,10 @@ loadDone:
 	editor.updateCurInstr = true; // setMouseBusy(false) is called in the input/video thread when done
 
 	if (numLoadedSamples > MAX_SMP_PER_INST)
-		okBoxThreadSafe(0, "System message", "Warning: The instrument contained >16 samples. The extra samples were discarded!");
+		okBoxThreadSafe(0, "System message", "Warning: The instrument contained >16 samples. The extra samples were discarded!", NULL);
 
 	if (stereoWarning)
-		okBoxThreadSafe(0, "System message", "Warning: The instrument contained stereo sample(s). They were mixed to mono!");
+		okBoxThreadSafe(0, "System message", "Warning: The instrument contained stereo sample(s). They were mixed to mono!", NULL);
 
 	return true;
 	(void)ptr;
@@ -3485,7 +3486,7 @@ void loadInstr(UNICHAR *filenameU)
 {
 	if (editor.curInstr == 0)
 	{
-		okBox(0, "System message", "The zero-instrument cannot hold intrument data.");
+		okBox(0, "System message", "The zero-instrument cannot hold intrument data.", NULL);
 		return;
 	}
 
@@ -3498,7 +3499,7 @@ void loadInstr(UNICHAR *filenameU)
 		thread = SDL_CreateThread(loadInstrThread, NULL, NULL);
 		if (thread == NULL)
 		{
-			okBox(0, "System message", "Couldn't create thread!");
+			okBox(0, "System message", "Couldn't create thread!", NULL);
 			return;
 		}
 
