@@ -244,7 +244,7 @@ static void handleKeys(SDL_Keycode keycode, SDL_Scancode scanKey)
 					config.masterVol = 0;
 
 				setAudioAmp(config.boostLevel, config.masterVol, !!(config.specialFlags & BITDEPTH_32));
-				if (ui.configScreenShown && editor.currConfigScreen == CONFIG_SCREEN_IO_DEVICES)
+				if (ui.configScreenShown && editor.currConfigScreen == CONFIG_SCREEN_AUDIO)
 					showConfigScreen();
 			}
 			else
@@ -277,7 +277,7 @@ static void handleKeys(SDL_Keycode keycode, SDL_Scancode scanKey)
 					config.masterVol = 256;
 
 				setAudioAmp(config.boostLevel, config.masterVol, !!(config.specialFlags & BITDEPTH_32));
-				if (ui.configScreenShown && editor.currConfigScreen == CONFIG_SCREEN_IO_DEVICES)
+				if (ui.configScreenShown && editor.currConfigScreen == CONFIG_SCREEN_AUDIO)
 					showConfigScreen();
 			}
 		}
@@ -296,7 +296,7 @@ static void handleKeys(SDL_Keycode keycode, SDL_Scancode scanKey)
 					if (editor.curInstr == 0 || instr[editor.curInstr] == NULL)
 						return;
 
-					if (okBox(1, "System request", "Clear instrument?") == 1)
+					if (okBox(1, "System request", "Clear instrument?", NULL) == 1)
 					{
 						freeInstr(editor.curInstr);
 						memset(song.instrName[editor.curInstr], 0, sizeof(song.instrName[editor.curInstr]));
@@ -615,9 +615,8 @@ static void handleKeys(SDL_Keycode keycode, SDL_Scancode scanKey)
 			if (audioWasntLocked)
 				lockAudio();
 
-			if (song.row >= 16)
-				song.row -= 16;
-			else
+			song.row -= 16;
+			if (song.row < 0)
 				song.row = 0;
 
 			if (!songPlaying)
@@ -637,9 +636,8 @@ static void handleKeys(SDL_Keycode keycode, SDL_Scancode scanKey)
 			if (audioWasntLocked)
 				lockAudio();
 
-			if (song.row < song.currNumRows-16)
-				song.row += 16;
-			else
+			song.row += 16;
+			if (song.row >= song.currNumRows)
 				song.row = song.currNumRows-1;
 
 			if (!songPlaying)
@@ -677,7 +675,7 @@ static void handleKeys(SDL_Keycode keycode, SDL_Scancode scanKey)
 			if (audioWasntLocked)
 				lockAudio();
 
-			song.row = patternNumRows[song.pattNum] - 1;
+			song.row = song.currNumRows - 1;
 			if (!songPlaying)
 			{
 				editor.row = (uint8_t)song.row;
@@ -776,30 +774,26 @@ static bool checkModifiedKeys(SDL_Keycode keycode)
 
 		case SDLK_a:
 		{
-#ifdef __APPLE__
-			if (keyb.leftAltPressed || keyb.leftCommandPressed)
-#else
-			if (keyb.leftAltPressed)
-#endif
+			if (ui.sampleEditorShown)
 			{
-				if (ui.sampleEditorShown)
-					rangeAll();
 #ifdef __APPLE__
-				else if (!keyb.leftCommandPressed) // yuck!
+				if (keyb.leftCtrlPressed || keyb.leftAltPressed || keyb.leftCommandPressed)
 #else
-				else
+				if (keyb.leftCtrlPressed || keyb.leftAltPressed)
 #endif
-					showAdvEdit();
-
+				{
+					rangeAll();
+					return true;
+				}
+			}
+			else if (keyb.leftCtrlPressed)
+			{
+				showAdvEdit();
 				return true;
 			}
 			else if (keyb.leftAltPressed)
 			{
-				if (ui.sampleEditorShown)
-					rangeAll();
-				else
-					jumpToChannel(8);
-
+				jumpToChannel(8);
 				return true;
 			}
 		}
@@ -1229,7 +1223,7 @@ static bool checkModifiedKeys(SDL_Keycode keycode)
 			{
 				editor.currConfigScreen = 0;
 				showConfigScreen();
-				checkRadioButton(RB_CONFIG_IO_DEVICES);
+				checkRadioButton(RB_CONFIG_AUDIO);
 
 				return true;
 			}
