@@ -260,25 +260,25 @@ void fixSample(sample_t *s)
 	*/
 	if (sample16Bit)
 	{
-		for (int32_t i = 0; i < SINC_LEFT_TAPS; i++)
-			ptr16[i-SINC_LEFT_TAPS] = ptr16[0];
+		for (int32_t i = 0; i < SINC_MAX_LEFT_TAPS; i++)
+			ptr16[i-SINC_MAX_LEFT_TAPS] = ptr16[0];
 	}
 	else
 	{
-		for (int32_t i = 0; i < SINC_LEFT_TAPS; i++)
-			s->dataPtr[i-SINC_LEFT_TAPS] = s->dataPtr[0];
+		for (int32_t i = 0; i < SINC_MAX_LEFT_TAPS; i++)
+			s->dataPtr[i-SINC_MAX_LEFT_TAPS] = s->dataPtr[0];
 	}
 
 	if (loopType == LOOP_OFF) // no loop
 	{
 		if (sample16Bit)
 		{
-			for (int32_t i = 0; i < SINC_RIGHT_TAPS; i++)
+			for (int32_t i = 0; i < SINC_MAX_RIGHT_TAPS; i++)
 				ptr16[length+i] = ptr16[length-1];
 		}
 		else
 		{
-			for (int32_t i = 0; i < SINC_RIGHT_TAPS; i++)
+			for (int32_t i = 0; i < SINC_MAX_RIGHT_TAPS; i++)
 				s->dataPtr[length+i] = s->dataPtr[length-1];
 		}
 
@@ -294,16 +294,16 @@ void fixSample(sample_t *s)
 	{
 		if (sample16Bit)
 		{
-			// left edge (we need SINC_TAPS amount of taps starting from the center tap)
-			for (int32_t i = -SINC_LEFT_TAPS; i < SINC_TAPS; i++)
+			// left edge (we need SINC_MAX_TAPS amount of taps starting from the center tap)
+			for (int32_t i = -SINC_MAX_LEFT_TAPS; i < SINC_MAX_TAPS; i++)
 			{
 				pos = loopStart + myMod(i, loopLength);
-				s->leftEdgeTapSamples16[SINC_LEFT_TAPS+i] = ptr16[pos];
+				s->leftEdgeTapSamples16[SINC_MAX_LEFT_TAPS+i] = ptr16[pos];
 			}
 
 			// right edge (change actual sample data since data after loop is never used)
 			pos = loopStart;
-			for (int32_t i = 0; i < SINC_RIGHT_TAPS; i++)
+			for (int32_t i = 0; i < SINC_MAX_RIGHT_TAPS; i++)
 			{
 				s->fixedSmp[i] = ptr16[loopEnd+i];
 				ptr16[loopEnd+i] = ptr16[pos];
@@ -314,16 +314,16 @@ void fixSample(sample_t *s)
 		}
 		else // 8-bit
 		{
-			// left edge (we need SINC_TAPS amount of taps starting from the center tap)
-			for (int32_t i = -SINC_LEFT_TAPS; i < SINC_TAPS; i++)
+			// left edge (we need SINC_MAX_TAPS amount of taps starting from the center tap)
+			for (int32_t i = -SINC_MAX_LEFT_TAPS; i < SINC_MAX_TAPS; i++)
 			{
 				pos = loopStart + myMod(i, loopLength);
-				s->leftEdgeTapSamples8[SINC_LEFT_TAPS+i] = s->dataPtr[pos];
+				s->leftEdgeTapSamples8[SINC_MAX_LEFT_TAPS+i] = s->dataPtr[pos];
 			}
 
 			// right edge (change actual sample data since data after loop is never used)
 			pos = loopStart;
-			for (int32_t i = 0; i < SINC_RIGHT_TAPS; i++)
+			for (int32_t i = 0; i < SINC_MAX_RIGHT_TAPS; i++)
 			{
 				s->fixedSmp[i] = s->dataPtr[loopEnd+i];
 				s->dataPtr[loopEnd+i] = s->dataPtr[pos];
@@ -337,10 +337,10 @@ void fixSample(sample_t *s)
 	{
 		if (sample16Bit)
 		{
-			// left edge (positive taps, we need SINC_TAPS amount of taps starting from the center tap)
+			// left edge (positive taps, we need SINC_MAX_TAPS amount of taps starting from the center tap)
 			pos = loopStart;
 			backwards = false;
-			for (int32_t i = 0; i < SINC_TAPS; i++)
+			for (int32_t i = 0; i < SINC_MAX_TAPS; i++)
 			{
 				if (backwards)
 				{
@@ -356,7 +356,7 @@ void fixSample(sample_t *s)
 					backwards = true;
 				}
 
-				s->leftEdgeTapSamples16[SINC_LEFT_TAPS+i] = ptr16[pos];
+				s->leftEdgeTapSamples16[SINC_MAX_LEFT_TAPS+i] = ptr16[pos];
 
 				if (backwards)
 					pos--;
@@ -365,13 +365,13 @@ void fixSample(sample_t *s)
 			}
 
 			// left edge (negative taps)
-			for (int32_t i = 0; i < SINC_LEFT_TAPS; i++)
-				s->leftEdgeTapSamples16[(SINC_LEFT_TAPS-1)-i] = s->leftEdgeTapSamples16[SINC_LEFT_TAPS+1+i];
+			for (int32_t i = 0; i < SINC_MAX_LEFT_TAPS; i++)
+				s->leftEdgeTapSamples16[(SINC_MAX_LEFT_TAPS-1)-i] = s->leftEdgeTapSamples16[SINC_MAX_LEFT_TAPS+1+i];
 
 			// right edge (change actual sample data since data after loop is never used)
 			pos = loopEnd-1;
 			backwards = true;
-			for (int32_t i = 0; i < SINC_RIGHT_TAPS; i++)
+			for (int32_t i = 0; i < SINC_MAX_RIGHT_TAPS; i++)
 			{
 				if (backwards)
 				{
@@ -398,10 +398,10 @@ void fixSample(sample_t *s)
 		}
 		else // 8-bit
 		{
-			// left edge (positive taps, we need SINC_TAPS amount of taps starting from the center tap)
+			// left edge (positive taps, we need SINC_MAX_TAPS amount of taps starting from the center tap)
 			pos = loopStart;
 			backwards = false;
-			for (int32_t i = 0; i < SINC_TAPS; i++)
+			for (int32_t i = 0; i < SINC_MAX_TAPS; i++)
 			{
 				if (backwards)
 				{
@@ -417,7 +417,7 @@ void fixSample(sample_t *s)
 					backwards = true;
 				}
 
-				s->leftEdgeTapSamples8[SINC_LEFT_TAPS+i] = s->dataPtr[pos];
+				s->leftEdgeTapSamples8[SINC_MAX_LEFT_TAPS+i] = s->dataPtr[pos];
 
 				if (backwards)
 					pos--;
@@ -426,13 +426,13 @@ void fixSample(sample_t *s)
 			}
 
 			// left edge (negative taps)
-			for (int32_t i = 0; i < SINC_LEFT_TAPS; i++)
-				s->leftEdgeTapSamples8[(SINC_LEFT_TAPS-1)-i] = s->leftEdgeTapSamples8[SINC_LEFT_TAPS+1+i];
+			for (int32_t i = 0; i < SINC_MAX_LEFT_TAPS; i++)
+				s->leftEdgeTapSamples8[(SINC_MAX_LEFT_TAPS-1)-i] = s->leftEdgeTapSamples8[SINC_MAX_LEFT_TAPS+1+i];
 
 			// right edge (change actual sample data since data after loop is never used)
 			pos = loopEnd-1;
 			backwards = true;
-			for (int32_t i = 0; i < SINC_RIGHT_TAPS; i++)
+			for (int32_t i = 0; i < SINC_MAX_RIGHT_TAPS; i++)
 			{
 				if (backwards)
 				{
@@ -470,13 +470,13 @@ void unfixSample(sample_t *s)
 	if (s->flags & SAMPLE_16BIT)
 	{
 		int16_t *ptr16 = (int16_t *)s->dataPtr + s->fixedPos;
-		for (int32_t i = 0; i < SINC_RIGHT_TAPS; i++)
+		for (int32_t i = 0; i < SINC_MAX_RIGHT_TAPS; i++)
 			ptr16[i] = s->fixedSmp[i];
 	}
 	else // 8-bit
 	{
 		int8_t *ptr8 = s->dataPtr + s->fixedPos;
-		for (int32_t i = 0; i < SINC_RIGHT_TAPS; i++)
+		for (int32_t i = 0; i < SINC_MAX_RIGHT_TAPS; i++)
 			ptr8[i] = (int8_t)s->fixedSmp[i];
 	}
 
@@ -728,7 +728,7 @@ static int32_t SDLCALL copySampleThread(void *ptr)
 
 error:
 	resumeAudio();
-	okBoxThreadSafe(0, "System message", "Not enough memory!");
+	okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 	return true;
 
 	(void)ptr;
@@ -743,7 +743,7 @@ void copySmp(void) // copy sample from srcInstr->srcSmp to curInstr->curSmp
 	thread = SDL_CreateThread(copySampleThread, NULL, NULL);
 	if (thread == NULL)
 	{
-		okBox(0, "System message", "Couldn't create thread!");
+		okBox(0, "System message", "Couldn't create thread!", NULL);
 		return;
 	}
 
@@ -818,7 +818,7 @@ static int32_t getScaledSample(sample_t *s, int32_t index) // for sample data vi
 		int16_t *ptr16 = (int16_t *)s->dataPtr;
 
 		// don't read fixed mixer interpolation samples, read the prestine ones instead
-		if (index >= s->fixedPos && index < s->fixedPos+SINC_RIGHT_TAPS && s->length > loopEnd && s->isFixed)
+		if (index >= s->fixedPos && index < s->fixedPos+SINC_MAX_RIGHT_TAPS && s->length > loopEnd && s->isFixed)
 			tmp32 = s->fixedSmp[index-s->fixedPos];
 		else
 			tmp32 = ptr16[index];
@@ -827,7 +827,7 @@ static int32_t getScaledSample(sample_t *s, int32_t index) // for sample data vi
 	}
 	else // 8-bit
 	{
-		if (index >= s->fixedPos && index < s->fixedPos+SINC_RIGHT_TAPS && s->length > loopEnd && s->isFixed)
+		if (index >= s->fixedPos && index < s->fixedPos+SINC_MAX_RIGHT_TAPS && s->length > loopEnd && s->isFixed)
 			tmp32 = s->fixedSmp[index-s->fixedPos];
 		else
 			tmp32 = s->dataPtr[index];
@@ -1095,7 +1095,7 @@ static void getMinMax8(const void *p, uint32_t scanLen, int8_t *min8, int8_t *ma
 	}
 }
 
-// for scanning sample data peak where loopEnd+SINC_RIGHT_TAPS is within scan range (fixed interpolation tap samples)
+// for scanning sample data peak where loopEnd+SINC_MAX_RIGHT_TAPS is within scan range (fixed interpolation tap samples)
 static void getSpecialMinMax16(sample_t *s, int32_t index, int32_t scanEnd, int16_t *min16, int16_t *max16)
 {
 	int16_t minVal2, maxVal2;
@@ -1114,7 +1114,7 @@ static void getSpecialMinMax16(sample_t *s, int32_t index, int32_t scanEnd, int1
 
 	// read fixed samples (we are guaranteed to be within the fixed samples here)
 	const int32_t tapIndex = index-s->fixedPos;
-	const int32_t scanLength = SINC_RIGHT_TAPS-tapIndex;
+	const int32_t scanLength = SINC_MAX_RIGHT_TAPS-tapIndex;
 
 	int32_t tmpScanEnd = index+scanLength;
 	if (tmpScanEnd > scanEnd)
@@ -1140,7 +1140,7 @@ static void getSpecialMinMax16(sample_t *s, int32_t index, int32_t scanEnd, int1
 	*max16 = maxVal;
 }
 
-// for scanning sample data peak where loopEnd+SINC_RIGHT_TAPS is within scan range (fixed interpolation tap samples)
+// for scanning sample data peak where loopEnd+SINC_MAX_RIGHT_TAPS is within scan range (fixed interpolation tap samples)
 static void getSpecialMinMax8(sample_t *s, int32_t index, int32_t scanEnd, int8_t *min8, int8_t *max8)
 {
 	int8_t minVal2, maxVal2;
@@ -1159,7 +1159,7 @@ static void getSpecialMinMax8(sample_t *s, int32_t index, int32_t scanEnd, int8_
 
 	// read fixed samples (we are guaranteed to be within the fixed samples here)
 	const int32_t tapIndex = index-s->fixedPos;
-	const int32_t scanLength = SINC_RIGHT_TAPS-tapIndex;
+	const int32_t scanLength = SINC_MAX_RIGHT_TAPS-tapIndex;
 
 	int32_t tmpScanEnd = index+scanLength;
 	if (tmpScanEnd > scanEnd)
@@ -1204,7 +1204,7 @@ static void getSampleDataPeak(sample_t *s, int32_t index, int32_t length, int16_
 		/* If the scan area is including the fixed samples (for branchless mixer interpolation),
 		** do a special procedure to scan the original non-touched samples when needed.
 		*/
-		const bool insideRange = index >= s->fixedPos && index < s->fixedPos+SINC_RIGHT_TAPS;
+		const bool insideRange = index >= s->fixedPos && index < s->fixedPos+SINC_MAX_RIGHT_TAPS;
 		if (insideRange || (index < s->fixedPos && scanEnd >= s->fixedPos))
 		{
 			if (s->flags & SAMPLE_16BIT)
@@ -1644,7 +1644,7 @@ void showRange(void)
 	}
 	else
 	{
-		okBox(0, "System message", "Cannot show empty range!");
+		okBox(0, "System message", "Cannot show empty range!", NULL);
 	}
 }
 
@@ -1829,7 +1829,7 @@ void saveRange(void)
 
 	if (smpEd_Rx1 == smpEd_Rx2)
 	{
-		okBox(0, "System message", "No range specified!");
+		okBox(0, "System message", "No range specified!", NULL);
 		return;
 	}
 
@@ -1839,19 +1839,19 @@ void saveRange(void)
 
 	if (smpEd_SysReqText[0] == '\0')
 	{
-		okBox(0, "System message", "Filename can't be empty!");
+		okBox(0, "System message", "Filename can't be empty!", NULL);
 		return;
 	}
 
 	if (smpEd_SysReqText[0] == '.')
 	{
-		okBox(0, "System message", "The very first character in the filename can't be '.' (dot)!");
+		okBox(0, "System message", "The very first character in the filename can't be '.' (dot)!", NULL);
 		return;
 	}
 
 	if (strpbrk(smpEd_SysReqText, "\\/:*?\"<>|") != NULL)
 	{
-		okBox(0, "System message", "The filename can't contain the following characters: \\ / : * ? \" < > |");
+		okBox(0, "System message", "The filename can't contain the following characters: \\ / : * ? \" < > |", NULL);
 		return;
 	}
 
@@ -1865,7 +1865,7 @@ void saveRange(void)
 	UNICHAR *filenameU = cp437ToUnichar(smpEd_SysReqText);
 	if (filenameU == NULL)
 	{
-		okBox(0, "System message", "Out of memory!");
+		okBox(0, "System message", "Not enough memory!", NULL);
 		return;
 	}
 
@@ -1873,7 +1873,7 @@ void saveRange(void)
 	{
 		char buf[256];
 		createFileOverwriteText(smpEd_SysReqText, buf);
-		if (okBox(2, "System request", buf) != 1)
+		if (okBox(2, "System request", buf, NULL) != 1)
 			return;
 	}
 
@@ -1904,7 +1904,7 @@ static bool cutRange(bool cropMode, int32_t r1, int32_t r2)
 				fixSample(s);
 				resumeAudio();
 
-				okBoxThreadSafe(0, "System message", "Not enough memory!");
+				okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 				return false;
 			}
 
@@ -1926,7 +1926,7 @@ static bool cutRange(bool cropMode, int32_t r1, int32_t r2)
 			if (!cropMode)
 				resumeAudio();
 
-			okBoxThreadSafe(0, "System message", "Not enough memory!");
+			okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 			return false;
 		}
 
@@ -1986,7 +1986,7 @@ static bool cutRange(bool cropMode, int32_t r1, int32_t r2)
 static int32_t SDLCALL sampCutThread(void *ptr)
 {
 	if (!cutRange(false, smpEd_Rx1, smpEd_Rx2))
-		okBoxThreadSafe(0, "System message", "Not enough memory! (Disable \"cut to buffer\")");
+		okBoxThreadSafe(0, "System message", "Not enough memory! (Disable \"cut to buffer\")", NULL);
 	else
 		writeSampleFlag = true;
 
@@ -2005,7 +2005,7 @@ void sampCut(void)
 	thread = SDL_CreateThread(sampCutThread, NULL, NULL);
 	if (thread == NULL)
 	{
-		okBox(0, "System message", "Couldn't create thread!");
+		okBox(0, "System message", "Couldn't create thread!", NULL);
 		return;
 	}
 
@@ -2020,7 +2020,7 @@ static int32_t SDLCALL sampCopyThread(void *ptr)
 
 	if (!getCopyBuffer(smpEd_Rx2- smpEd_Rx1, sample16Bit))
 	{
-		okBoxThreadSafe(0, "System message", "Not enough memory!");
+		okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 		return true;
 	}
 
@@ -2053,7 +2053,7 @@ void sampCopy(void)
 	thread = SDL_CreateThread(sampCopyThread, NULL, NULL);
 	if (thread == NULL)
 	{
-		okBox(0, "System message", "Couldn't create thread!");
+		okBox(0, "System message", "Couldn't create thread!", NULL);
 		return;
 	}
 
@@ -2066,7 +2066,7 @@ static void pasteOverwrite(sample_t *s)
 
 	if (!reallocateSmpData(s, smpCopySize, sample16Bit))
 	{
-		okBoxThreadSafe(0, "System message", "Not enough memory!");
+		okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 		return;
 	}
 
@@ -2152,7 +2152,7 @@ static int32_t SDLCALL sampPasteThread(void *ptr)
 
 	if (instr[editor.curInstr] == NULL && !allocateInstr(editor.curInstr))
 	{
-		okBoxThreadSafe(0, "System message", "Not enough memory!");
+		okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 		return true;
 	}
 
@@ -2167,7 +2167,7 @@ static int32_t SDLCALL sampPasteThread(void *ptr)
 
 	if (s->length+smpCopySize > MAX_SAMPLE_LEN)
 	{
-		okBoxThreadSafe(0, "System message", "Not enough room in sample!");
+		okBoxThreadSafe(0, "System message", "Not enough room in sample!", NULL);
 		return true;
 	}
 
@@ -2177,13 +2177,13 @@ static int32_t SDLCALL sampPasteThread(void *ptr)
 
 	if (newLength > MAX_SAMPLE_LEN)
 	{
-		okBoxThreadSafe(0, "System message", "Not enough room in sample!");
+		okBoxThreadSafe(0, "System message", "Not enough room in sample!", NULL);
 		return true;
 	}
 
 	if (!allocateSmpDataPtr(&sp, newLength, sample16Bit))
 	{
-		okBoxThreadSafe(0, "System message", "Not enough memory!");
+		okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 		return true;
 	}
 
@@ -2255,7 +2255,7 @@ void sampPaste(void)
 		sample_t *s = getCurSample();
 		if (s != NULL && s->dataPtr != NULL && s->length > 0)
 		{
-			if (okBox(2, "System request", "The current sample is not empty. Do you really want to overwrite it?") != 1)
+			if (okBox(2, "System request", "The current sample is not empty. Do you really want to overwrite it?", NULL) != 1)
 				return;
 		}
 	}
@@ -2264,7 +2264,7 @@ void sampPaste(void)
 	thread = SDL_CreateThread(sampPasteThread, NULL, NULL);
 	if (thread == NULL)
 	{
-		okBox(0, "System message", "Couldn't create thread!");
+		okBox(0, "System message", "Couldn't create thread!", NULL);
 		return;
 	}
 
@@ -2319,7 +2319,7 @@ void sampCrop(void)
 	thread = SDL_CreateThread(sampCropThread, NULL, NULL);
 	if (thread == NULL)
 	{
-		okBox(0, "System message", "Couldn't create thread!");
+		okBox(0, "System message", "Couldn't create thread!", NULL);
 		return;
 	}
 
@@ -2337,21 +2337,21 @@ void sampXFade(void)
 	// check if the sample has the loop flag enabled
 	if (GET_LOOPTYPE(s->flags) == LOOP_OFF)
 	{
-		okBox(0, "System message", "X-Fade can only be used on a loop-enabled sample!");
+		okBox(0, "System message", "X-Fade can only be used on a loop-enabled sample!", NULL);
 		return;
 	}
 
 	// check if we selected a range
 	if (smpEd_Rx2 == 0)
 	{
-		okBox(0, "System message", "No range selected! Make a small range that includes loop start or loop end.");
+		okBox(0, "System message", "No range selected! Make a small range that includes loop start or loop end.", NULL);
 		return;
 	}
 
 	// check if we selected a valid range length
 	if (smpEd_Rx2-smpEd_Rx1 <= 2)
 	{
-		okBox(0, "System message", "Invalid range!");
+		okBox(0, "System message", "Invalid range!", NULL);
 		return;
 	}
 
@@ -2367,7 +2367,7 @@ void sampXFade(void)
 		{
 			if (x2 <= y1 || x2 >= s->loopStart+s->loopLength)
 			{
-				okBox(0, "System message", "Error: No loop point found inside marked data.");
+				okBox(0, "System message", "Error: No loop point found inside marked data.", NULL);
 				return;
 			}
 
@@ -2380,13 +2380,13 @@ void sampXFade(void)
 
 			if (d1 < 1 || d2 < 1 || d3 < 1)
 			{
-				okBox(0, "System message", "Invalid range! Try to mark more data.");
+				okBox(0, "System message", "Invalid range! Try to mark more data.", NULL);
 				return;
 			}
 
 			if (y1-d1 < 0 || y1+d1 >= s->length)
 			{
-				okBox(0, "System message", "Not enough sample data outside loop!");
+				okBox(0, "System message", "Not enough sample data outside loop!", NULL);
 				return;
 			}
 
@@ -2430,7 +2430,7 @@ void sampXFade(void)
 			y1 += s->loopLength;
 			if (x1 >= y1 || x2 <= y1 || x2 >= s->length)
 			{
-				okBox(0, "System message", "Error: No loop point found inside marked data.");
+				okBox(0, "System message", "Error: No loop point found inside marked data.", NULL);
 				return;
 			}
 
@@ -2443,13 +2443,13 @@ void sampXFade(void)
 
 			if (d1 < 1 || d2 < 1 || d3 < 1)
 			{
-				okBox(0, "System message", "Invalid range! Try to mark more data.");
+				okBox(0, "System message", "Invalid range! Try to mark more data.", NULL);
 				return;
 			}
 
 			if (y1-d1 < 0 || y1+d1 >= s->length)
 			{
-				okBox(0, "System message", "Not enough sample data outside loop!");
+				okBox(0, "System message", "Not enough sample data outside loop!", NULL);
 				return;
 			}
 
@@ -2499,7 +2499,7 @@ void sampXFade(void)
 
 		if (x1 < 0 || x2 <= x1 || x2 >= s->length)
 		{
-			okBox(0, "System message", "Invalid range!");
+			okBox(0, "System message", "Invalid range!", NULL);
 			return;
 		}
 
@@ -2511,7 +2511,7 @@ void sampXFade(void)
 
 		if (y1 < 0 || y2+length >= s->length)
 		{
-			okBox(0, "System message", "Not enough sample data outside loop!");
+			okBox(0, "System message", "Not enough sample data outside loop!", NULL);
 			return;
 		}
 
@@ -2521,7 +2521,7 @@ void sampXFade(void)
 
 		if (y1+length <= s->loopStart || d1 == 0 || d3 == 0 || d1 > s->loopLength)
 		{
-			okBox(0, "System message", "Invalid range!");
+			okBox(0, "System message", "Invalid range!", NULL);
 			return;
 		}
 
@@ -2680,13 +2680,13 @@ void rbSample8bit(void)
 	if (s == NULL || s->dataPtr == NULL || s->length <= 0)
 		return;
 
-	if (okBox(2, "System request", "Convert sampledata?") == 1)
+	if (okBox(2, "System request", "Pre-convert sample data?", NULL) == 1)
 	{
 		mouseAnimOn();
 		thread = SDL_CreateThread(convSmp8Bit, NULL, NULL);
 		if (thread == NULL)
 		{
-			okBox(0, "System message", "Couldn't create thread!");
+			okBox(0, "System message", "Couldn't create thread!", NULL);
 			return;
 		}
 
@@ -2720,7 +2720,7 @@ static int32_t SDLCALL convSmp16Bit(void *ptr)
 
 	if (!reallocateSmpData(s, s->length, true))
 	{
-		okBoxThreadSafe(0, "System message", "Not enough memory!");
+		okBoxThreadSafe(0, "System message", "Not enough memory!", NULL);
 		return true;
 	}
 
@@ -2748,13 +2748,13 @@ void rbSample16bit(void)
 	if (s == NULL || s->dataPtr == NULL || s->length <= 0)
 		return;
 
-	if (okBox(2, "System request", "Convert sampledata?") == 1)
+	if (okBox(2, "System request", "Pre-convert sample data?", NULL) == 1)
 	{
 		mouseAnimOn();
 		thread = SDL_CreateThread(convSmp16Bit, NULL, NULL);
 		if (thread == NULL)
 		{
-			okBox(0, "System message", "Couldn't create thread!");
+			okBox(0, "System message", "Couldn't create thread!", NULL);
 			return;
 		}
 
@@ -2785,7 +2785,7 @@ void clearSample(void)
 	if (s == NULL || s->dataPtr == NULL || s->length <= 0)
 		return;
 
-	if (okBox(1, "System request", "Clear sample?") != 1)
+	if (okBox(1, "System request", "Clear sample?", NULL) != 1)
 		return;
 
 	freeSample(editor.curInstr, editor.curSmp);
@@ -2802,17 +2802,17 @@ void sampMinimize(void)
 	const bool hasLoop = GET_LOOPTYPE(s->flags) != LOOP_OFF;
 	if (!hasLoop)
 	{
-		okBox(0, "System message", "Only a looped sample can be minimized!");
+		okBox(0, "System message", "Only a looped sample can be minimized!", NULL);
 		return;
 	}
 
 	if (s->loopStart+s->loopLength >= s->length)
 	{
-		okBox(0, "System message", "The sample can't be minimized any further.");
+		okBox(0, "System message", "This sample is already minimized.", NULL);
 		return;
 	}
 
-	if (okBox(1, "System request", "Minimize sample?") != 1)
+	if (okBox(1, "System request", "Minimize sample?", NULL) != 1)
 		return;
 	
 	lockMixerCallback();
@@ -3613,7 +3613,7 @@ void sampleBackwards(void)
 	thread = SDL_CreateThread(sampleBackwardsThread, NULL, NULL);
 	if (thread == NULL)
 	{
-		okBox(0, "System message", "Couldn't create thread!");
+		okBox(0, "System message", "Couldn't create thread!", NULL);
 		return;
 	}
 
@@ -3662,7 +3662,7 @@ void sampleChangeSign(void)
 	thread = SDL_CreateThread(sampleChangeSignThread, NULL, NULL);
 	if (thread == NULL)
 	{
-		okBox(0, "System message", "Couldn't create thread!");
+		okBox(0, "System message", "Couldn't create thread!", NULL);
 		return;
 	}
 
@@ -3708,7 +3708,7 @@ void sampleByteSwap(void)
 
 	if (!(s->flags & SAMPLE_16BIT))
 	{
-		if (okBox(2, "System request", "Byte swapping only makes sense on a 16-bit sample. Continue?") != 1)
+		if (okBox(2, "System request", "Byte swapping rarely makes sense on an 8-bit sample. Continue?", NULL) != 1)
 			return;
 	}
 
@@ -3716,7 +3716,7 @@ void sampleByteSwap(void)
 	thread = SDL_CreateThread(sampleByteSwapThread, NULL, NULL);
 	if (thread == NULL)
 	{
-		okBox(0, "System message", "Couldn't create thread!");
+		okBox(0, "System message", "Couldn't create thread!", NULL);
 		return;
 	}
 
@@ -3828,7 +3828,7 @@ void fixDC(void)
 	thread = SDL_CreateThread(fixDCThread, NULL, NULL);
 	if (thread == NULL)
 	{
-		okBox(0, "System message", "Couldn't create thread!");
+		okBox(0, "System message", "Couldn't create thread!", NULL);
 		return;
 	}
 
